@@ -42,7 +42,7 @@ class MiscTests(unittest.TestCase):
         aaf.fit(t,npX)
         aaf.fit(t, dfX)
         npt.assert_array_equal( c, aaf.cumulative_hazards_.columns[:3] )
-    """
+    
     def test_datetimes_to_durations_days(self):
         start_date = ['2013-10-10 0:00:00', '2013-10-09', '2012-10-10']
         end_date = ['2013-10-13', '2013-10-10 0:00:00', '2013-10-15']
@@ -66,7 +66,7 @@ class MiscTests(unittest.TestCase):
         npt.assert_almost_equal(T, np.array([1,24,3]) )
         npt.assert_almost_equal(C, np.array([1,1,1], dtype=bool) )
         return
-    """
+    
     def test_datetimes_to_durations_censor(self):
         start_date = ['2013-10-10', '2013-10-09', '2012-10-10']
         end_date = ['2013-10-13', None, '']
@@ -81,7 +81,14 @@ class MiscTests(unittest.TestCase):
         npt.assert_almost_equal(C, np.array([1,0,0], dtype=bool) )
         return
 
-
+    """
+    def test_datetimes_to_durations_max_dates(self):
+        start_date = ['2013-10-10', '2013-10-09', '2013-10-08']
+        end_date =  ['2014-10-10', '2014-10-09', '2014-10-08']
+        T,C = datetimes_to_durations(start_date, end_date, fill_date = "2014-10-09" )
+        npt.assert_almost_equal(C, np.array([1,0,0], dtype=bool) )
+        return
+    """
 class StatisticalTests(unittest.TestCase):
 
   def setUp(self):
@@ -284,10 +291,10 @@ class StatisticalTests(unittest.TestCase):
       T_max = aaf.timeline[-10]
       #plot baby
       for i,column in enumerate(coef.columns):
-        ax = plt.subplot(d+2,1,i+1)
-        ax.plot( timeline[timeline<T_max], cumulative_hazards[timeline<T_max,i])
-        aaf.plot(ax=ax, columns=[column],  iloc=slice(0,500))
-        ax.legend(loc='lower right')
+          ax = plt.subplot(d+2,1,i+1)
+          ax.plot( timeline[timeline<T_max], cumulative_hazards[timeline<T_max,i])
+          aaf.plot(ax=ax, columns=[column],  iloc=slice(0,200))
+          ax.legend(loc='lower right')
 
       ax = plt.subplot(d+2,1,d+2)
       ax.plot( (T > np.arange(T_max)).sum(0), c="k", label="number of observations" )
@@ -372,6 +379,44 @@ class StatisticalTests(unittest.TestCase):
 
 class PlottingTests(unittest.TestCase):
 
+  def test_aalen_additive_plot(self):
+      #this is a visual test of the fitting the cumulative
+      #hazards.
+      n = 2500
+      d = 3
+      timeline = np.linspace(0,70,5000)
+      hz, coef, X = generate_hazard_rates(n, d, timeline)
+      cumulative_hazards = cumulative_quadrature( coef.values.T, timeline).T
+      T = generate_random_lifetimes(hz, timeline)
+      C = np.random.binomial(1, 0.8, size=n)
+
+      #fit the aaf, no intercept as it is already built into X, X[2] is ones
+      aaf = AalenAdditiveFitter(penalizer=0., fit_intercept=False)
+      aaf.fit(T,X, censorship=C, columns = coef.columns)
+      ax=aaf.plot(iloc=slice(0, aaf.cumulative_hazards_.shape[0]-100))
+      ax.set_xlabel("time")
+      ax.set_title('.plot() cumulative hazards')
+      return
+
+  def test_aalen_additive_smoothed_plot(self):
+      #this is a visual test of the fitting the cumulative
+      #hazards.
+      n = 2500
+      d = 3
+      timeline = np.linspace(0,150,5000)
+      hz, coef, X = generate_hazard_rates(n, d, timeline)
+      cumulative_hazards = cumulative_quadrature( coef.values.T, timeline).T
+      T = generate_random_lifetimes(hz, timeline) + 0.1*np.random.uniform(size=(n,1))
+      C = np.random.binomial(1, 0.8, size=n)
+
+      #fit the aaf, no intercept as it is already built into X, X[2] is ones
+      aaf = AalenAdditiveFitter(penalizer=0., fit_intercept=False)
+      aaf.fit(T,X, censorship=C, columns = coef.columns)
+      ax=aaf.smoothed_hazards_(1).iloc[0:aaf.cumulative_hazards_.shape[0]-500].plot()
+      ax.set_xlabel("time")
+      ax.set_title('.plot() smoothed hazards')
+      return
+
   def test_kmf_plotting(self):
       data1 = np.random.exponential(10, size=(100))
       data2 = np.random.exponential(2, size=(200,1))
